@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2016
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -90,7 +90,7 @@ QTps <- function(x, Y, ..., f.start = NULL, psi.scale = NULL,
     f.cv <- obj$fitted.values/(1 - diag.A) - diag.A * Y.psuedo/(1 - 
         diag.A)
     # leave-one-out estimate of f.hat
-    CV.psuedo <- mean(qsreg.rho(Y - f.cv, alpha = alpha, C = psi.scale))
+    CV.psuedo <- mean(qsreg.sigma(Y - f.cv, alpha = alpha, C = psi.scale))
     # add extra stuff to the Krig object.
     Qinfo <- list(yraw = Y, conv.info = conv.info, conv.flag = conv.flag, 
         CV.psuedo = CV.psuedo, psi.scale = psi.scale, alpha = alpha)
