@@ -76,8 +76,9 @@
             image(..., breaks=breaks, add = add, col = col)
         }
         else {
-            poly.image(..., add = add, col = col, midpoint = midpoint, 
-                border = border, lwd.poly = lwd)
+            poly.image(..., add = add,breaks=breaks, col = col,
+                       midpoint = midpoint, 
+                    border = border, lwd.poly = lwd)
         }
         big.par <- par(no.readonly = TRUE)
     }
@@ -141,7 +142,7 @@
     # notice how all the information is in the list axis.args
     do.call("axis", axis.args)
     # add a box around legend strip
-    box()
+    # box() 
     #
     # add a label to the axis if information has been  supplied
     # using the mtext function. The arguments to mtext are
