@@ -19,9 +19,13 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2    
 "image.smooth" <- function(x, wght = NULL, dx = 1, 
-    dy = 1, kernel.function = double.exp, theta = 1, grid = NULL, 
-    tol = 1e-08, xwidth = NULL, ywidth = NULL, weights = NULL, 
+    dy = 1, kernel.function = double.exp, aRange = 1, grid = NULL, 
+    tol = 1e-08, xwidth = NULL, ywidth = NULL, weights = NULL, theta=NULL,
     ...) {
+    # theta argument has been depreciated.
+    if( !is.null( theta)){
+        aRange<- theta
+    }
     # first part of this function is figuring what has been passed and
     # what to do
     if (is.list(x)) {
@@ -71,7 +75,7 @@
     if (is.null(wght)) {
         wght <- setup.image.smooth(nrow = m, ncol = n, xwidth = xwidth, 
             ywidth = ywidth, dx = dx, dy = dy, kernel.function = kernel.function, 
-            theta = theta,...)
+            aRange = aRange,...)
     }
     M <- nrow(wght$W)
     N <- ncol(wght$W)
