@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2016
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -36,18 +36,18 @@
     c1 <- c(c1, "Residual degrees of freedom:")
     c2 <- c(c2, format(round(length(x$residuals) - x$eff.df, 
         1)))
-    c1 <- c(c1, "GCV estimate for sigma:")
-    c2 <- c(c2, format(signif(x$shat.GCV, digits)))
+    c1 <- c(c1, "GCV estimate for tau:")
+    c2 <- c(c2, format(signif(x$tauHat.GCV, digits)))
+    c1 <- c(c1, "MLE for tau:")
+    c2 <- c(c2, format(signif(x$tauHat.MLE, digits)))
     c1 <- c(c1, "MLE for sigma:")
-    c2 <- c(c2, format(signif(x$shat.MLE, digits)))
-    c1 <- c(c1, "MLE for rho:")
-    c2 <- c(c2, format(signif(x$rho.MLE, digits)))
+    c2 <- c(c2, format(signif(x$sigma.MLE, digits)))
     c1 <- c(c1, "lambda")
     c2 <- c(c2, format(signif(x$lambda, 2)))
-    c1 <- c(c1, "User supplied rho")
-    c2 <- c(c2, format(signif(x$rho, digits)))
-    c1 <- c(c1, "User supplied sigma^2")
-    c2 <- c(c2, format(signif(x$sigma2, digits)))
+    c1 <- c(c1, "User supplied sigma")
+    c2 <- c(c2, format(signif(x$sigma, digits)))
+    c1 <- c(c1, "User supplied tau^2")
+    c2 <- c(c2, format(signif(x$tau2, digits)))
     sum <- cbind(c1, c2)
     dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
     cat("Call:\n")
