@@ -33,14 +33,14 @@ twoI3 = I3*2
 test.for.zero(twoI3, I3, tag="addToDiag")
 
 # turning spam on and off
-Krig(x,y, cov.function = "stationary.taper.cov", theta=1.5,
+Krig(x,y, cov.function = "stationary.taper.cov", aRange=1.5,
      cov.args= list( spam.format=FALSE,
-                     Taper.args= list( theta=2.0,k=2, dimension=2) )
+                     Taper.args= list( aRange=2.0,k=2, dimension=2) )
 ) -> out1
 
-Krig(x,y, cov.function = "stationary.taper.cov", lambda=2.0, theta=1.5,
+Krig(x,y, cov.function = "stationary.taper.cov", lambda=2.0, aRange=1.5,
      cov.args= list( spam.format=TRUE,
-                     Taper.args= list( theta=2.0,k=2, dimension=2) )
+                     Taper.args= list( aRange=2.0,k=2, dimension=2) )
 ) -> out2
 
 temp1<- predict( out1,lambda=2.0)
@@ -54,10 +54,10 @@ x<- x[good,]
 y<- y[good]
 
 # now look at mKrig w/o sparse matrix 
-mKrig( x,y, cov.function="stationary.cov", theta=10, lambda=.3,
+mKrig( x,y, cov.function="stationary.cov", aRange=10, lambda=.3,
        chol.args=list( pivot=FALSE))-> look
 
-Krig( x,y, cov.function="stationary.cov", theta=10, lambda=.3) -> look2
+Krig( x,y, cov.function="stationary.cov", aRange=10, lambda=.3) -> look2
 
 test.for.zero( look$d, look2$d, tag="Krig mKrig d coef")
 test.for.zero( look$c, look2$c, tag="Krig mKrig c coef")
@@ -75,7 +75,7 @@ Y<- cbind( runif(N), y,runif(N), y)
 
 # collapse == FALSE means each fixed effect found separately for columns of Y
 lookY<- mKrig( x,Y, cov.function="stationary.cov", 
-       theta=10, lambda=.3,collapse=FALSE)
+       aRange=10, lambda=.3,collapse=FALSE)
 temp3<-  predict( lookY, xnew, collapse=FALSE)[,4]
 
 test.for.zero( temp, temp3, tag="test of matrix Y predicts" )
@@ -90,10 +90,10 @@ test.for.zero( temp$z[good], temp2$z[good])
 # and also surface prediction
 
 N<- length( y)
-mKrig( x,y, cov.function="stationary.taper.cov", theta=2, 
+mKrig( x,y, cov.function="stationary.taper.cov", aRange=2, 
        spam.format=FALSE, lambda=.35 )-> look
 
-Krig( x,y, cov.function="stationary.taper.cov", theta=2, 
+Krig( x,y, cov.function="stationary.taper.cov", aRange=2, 
       spam.format=FALSE, lambda=.35)-> look2
 
 predictSurface( look, nx=50, ny=45)-> temp
@@ -105,13 +105,13 @@ test.for.zero( temp$z[good], temp2$z[good], tag="predictSurface with mKrig")
 # 
 # Use Wendland with sparse off and on.
 Krig( x,y, cov.function="wendland.cov", 
-      cov.args=list( k=2, theta=2.8), 
+      cov.args=list( k=2, aRange=2.8), 
       lambda=.3, spam.format=FALSE)-> look
 
-mKrig( x,y, cov.function="wendland.cov",k=2, theta=2.8,
+mKrig( x,y, cov.function="wendland.cov",k=2, aRange=2.8,
        spam.format=FALSE, lambda=.3)-> look2
 
-mKrig( x,y, cov.function="wendland.cov",k=2, theta=2.8,
+mKrig( x,y, cov.function="wendland.cov",k=2, aRange=2.8,
        spam.format=TRUE, lambda=.3)-> look3
 
 # final tests for  predict.
@@ -128,14 +128,15 @@ test.for.zero( temp2, temp3, tag="Wendland/spam")
 mKrig.coef( look2, cbind(y+1,y+2), collapse=FALSE)-> newc
 test.for.zero( look2$c, newc$c[,2], tag="new coef c no spam")
 
-test.for.zero( look2$d,
-               c(newc$d[1,2] -2, newc$d[2:3,2]), tag="new d coef no spam")
+test.for.zero( look2$beta,
+               c(newc$beta[1,2] -2, newc$beta[2:3,2]), tag="new beta coef no spam")
 
 mKrig.coef( look3, cbind(y+1,y+2), collapse=FALSE)-> newc
-test.for.zero( look3$c, newc$c[,2], tag="new coef c spam")
+test.for.zero( look3$c.coef, newc$c.coef[,2], tag="new coef c spam")
 
-test.for.zero( look3$d,
-               c(newc$d[1,2] -2, newc$d[2:3,2]), tag="new d coef spam")
+test.for.zero( look3$beta,
+               c(newc$beta[1,2] -2, newc$beta[2:3,2]), 
+               tag="new beta coef spam")
 
 ###
 
@@ -145,11 +146,11 @@ set.seed( 334)
 N<- 1000
 x<- matrix( runif(2*N),ncol=2)
 y<- rnorm( N)
-nzero <- length( wendland.cov(x,x, k=2,theta=.1)@entries)
+nzero <- length( wendland.cov(x,x, k=2,aRange=.1)@entries)
 
 
 mKrig( x,y, cov.function="wendland.cov",k=2,
-       theta=.1, lambda=.3)-> look2
+       aRange=.1, lambda=.3)-> look2
 
 
 test.for.zero( look2$non.zero.entires, nzero, tag="nzero in call to mKrig")
@@ -165,10 +166,10 @@ x<- ozone2$lon.lat[good,]
 
 # interpolate using defaults (Exponential)
 # stationary covariance
-mKrig( x,y, theta = 1.5, lambda=.2)-> out
+mKrig( x,y, aRange = 1.5, lambda=.2)-> out
 #
 # NOTE this should be identical to 
-Krig( x,y, theta=1.5, lambda=.2) -> out2
+Krig( x,y, aRange=1.5, lambda=.2) -> out2
 temp<- predict( out)
 temp2<- predict( out2)
 
@@ -183,12 +184,12 @@ y<- sin( 3*pi*x[,1])*sin( 3.5*pi*x[,2]) + rnorm( N)*.01
 
 
 Krig( x,y, Covariance="Wendland",
-      cov.args= list(k=2, theta=.8, dimension=2),                   , 
+      cov.args= list(k=2, aRange=.8, dimension=2),                   , 
       give.warnings=FALSE,
       lambda=1e2) -> out
 
 mKrig( x,y, 
-       cov.function="wendland.cov",k=2, theta=.8, 
+       cov.function="wendland.cov",k=2, aRange=.8, 
        lambda=1e2, 
        chol.args=list( memory=list( nnzR=1e5)), 
 )-> out2
@@ -196,7 +197,7 @@ mKrig( x,y,
 temp<- predict( out)
 temp2<- predict( out2)
 
-test.for.zero( temp, temp2, tag="predict Wendland  mKrig vs Krig")
+test.for.zero( temp, temp2, tol=1e-7, tag="predict Wendland  mKrig vs Krig")
 
 
 
@@ -214,13 +215,13 @@ set.seed( 222)
 ind<- sample( 1:(nx*ny), 600)
 xdat<- xg[ind,]
 ydat <- ztrue[ind]
-out<- fastTps(xdat, ydat, theta=.3)
+out<- fastTps(xdat, ydat, aRange=.3)
 out.p<-predictSurface( out, grid=gl, extrap=TRUE)
 # perfect agreement at data
-test.for.zero( ydat, c( out.p$z)[ind], tag="fastTps interp1")
+test.for.zero( ydat, c( out.p$z)[ind],tol=5e-7, tag="fastTps interp1")
 #image.plot(x,y,matrix( ztrue, nx,ny)- out.p$z) 
 rmse<- sqrt(mean( (ztrue- c( out.p$z))^2)/ mean( (ztrue)^2))
-test.for.zero( rmse,0,tol=0.02, relative=FALSE,tag="fastTps interp2")
+test.for.zero( rmse,0,tol=.02, relative=FALSE,tag="fastTps interp2")
 
 
 ##### test precomputing distance matrices:
@@ -244,17 +245,17 @@ distMat = rdist(x)
 ##### test using distance matrix
 print("testing using distance matrix")
 
-mKrig(x,y, cov.function = "stationary.cov", lambda=2.0, theta=1.5) -> out1
+mKrig(x,y, cov.function = "stationary.cov", lambda=2.0, aRange=1.5) -> out1
 
 mKrig(x,y, cov.args= list(Covariance="Exponential", Distance="rdist", Dist.args=list(compact=TRUE)), 
-      lambda=2.0, theta=1.5) -> out2
+      lambda=2.0, aRange=1.5) -> out2
 
 #NOTE: compact distance matrix should not be used by user for fields compatibility reasons
 mKrig(x,y, cov.args= list(Covariance="Exponential", Dist.args=list(compact=TRUE)), 
-      lambda=2.0, theta=1.5, distMat=compactDistMat) -> out3
+      lambda=2.0, aRange=1.5, distMat=compactDistMat) -> out3
 
 mKrig(x,y, cov.args= list(Covariance="Exponential"), 
-      lambda=2.0, theta=1.5, distMat=distMat) -> out4
+      lambda=2.0, aRange=1.5, distMat=distMat) -> out4
 
 temp1<- predict( out1)
 temp2<- predict( out2)
