@@ -24,14 +24,14 @@ y<- rnorm(10)
 
 
 lambda<- .1
-theta<- .2
-out<- mKrig( x,y, theta= theta, lambda=lambda)
+aRange<- .2
+out<- mKrig( x,y, aRange= aRange, lambda=lambda)
 
 test.for.zero( out$lnDetOmega,
 2*log( prod(diag(chol(out$Omega))))
 )
     
-Mc<-   exp( -rdist( x,x)/theta) + lambda* diag( 1,10)
+Mc<-   exp( -rdist( x,x)/aRange) + lambda* diag( 1,10)
 OmegaTest<- solve(t(out$Tmatrix)%*%solve( Mc)%*% out$Tmatrix)
 
 test.for.zero( OmegaTest, out$Omega,tag= "mKrigOmega")
@@ -44,7 +44,7 @@ test.for.zero( log( det( Mc)), out$lnDetCov, tag="lnDetMc" )
 set.seed( 323)
 x<- matrix( runif( 20), 10, 2)
 temp<-  matrix( NA, 50,8)
-thetaGrid<- seq( .1,.5, ,50)
+aRangeGrid<- seq( .1,.5, ,50)
 lambdaGrid<- 10**(runif( 50, -2,0))
 Q<- qr.qy( qr( cbind( rep(1,10),x) ), diag( 1,10))
 Q2<- Q[,4:10]
@@ -56,24 +56,24 @@ testDet<- function(lambda, obj)
   u2 <- obj$matrices$u[obj$matrices$D > 0]
   lD <- D2 * lambda
   N2 <- length(D2)
-  rho.MLE <- (sum((D2 * (u2)^2)/(1 + lD)))/N2
+  sigma.MLE <- (sum((D2 * (u2)^2)/(1 + lD)))/N2
   lnDetCov <- -sum(log(D2/(1 + lD)))
-#  -1 * (-N2/2 - log(2 * pi) * (N2/2) - (N2/2) * log(rho.MLE) - 
+#  -1 * (-N2/2 - log(2 * pi) * (N2/2) - (N2/2) * log(sigma.MLE) - 
 #          (1/2) * lnDetCov)
-  return( c(lnDetCov, rho.MLE) )
+  return( c(lnDetCov, sigma.MLE) )
 }
 
 for ( k in 1:50) {
-  out<- mKrig( x,y,  theta = thetaGrid[k], 
+  out<- mKrig( x,y,  aRange = aRangeGrid[k], 
                     lambda = lambdaGrid[k] 
                )
 # turn off warnings for lambda search because all we want are
 # matrix decompositions independent of lambda
-  out2<- Krig( x,y, theta= thetaGrid[k],
+  out2<- Krig( x,y, aRange= aRangeGrid[k],
                cov.args=list( Covariance = "Exponential"),
                             give.warnings=FALSE)
              
-  Mc<-   exp( -rdist( x,x)/thetaGrid[k] ) + lambdaGrid[k]* diag( 1,10)
+  Mc<-   exp( -rdist( x,x)/aRangeGrid[k] ) + lambdaGrid[k]* diag( 1,10)
   X<- out$Tmatrix
   temp[k,]<-c(
       out$lnDetCov,
@@ -81,8 +81,8 @@ for ( k in 1:50) {
       log( det( solve(t( Q2)%*%Mc%*%Q2) ) ),
       log( det(Mc) ),
       -1*log( det( t(X)%*%solve(Mc)%*%X ) ),
-      testDet( lambdaGrid[k], out2 ),
-      out$rho.MLE
+    testDet( lambdaGrid[k], out2 ),
+      out$summary["sigma2"]
       )
 }
 
@@ -96,12 +96,9 @@ test.for.zero( mean(resid), resid, relative=FALSE,
 #
 test.for.zero( temp[,3], -temp[,6], 
                tag="Q2 Det and Eigen Det")
-###### testing rho.MLE from mKrig and Krig
+###### testing sigma.MLE from mKrig and Krig
 
 test.for.zero( (7/10)*temp[,7],  temp[,8], 
-               tag="rho.MLE Krig verses mKrig")
+               tag="sigma.MLE Krig verses mKrig")
 
 
-#lm.out<-lm( temp[,1]~ temp[,c(2:3)])
-#summary( lm.out)
-
